@@ -1,6 +1,6 @@
 #! python3  # noqa: E265
 
-import logging
+import warnings
 
 # submodules
 from .__about__ import __version__  # noqa: F401
@@ -12,10 +12,11 @@ try:
     ES_ENABLED = True
     from .database import ElasticSearchManager  # noqa: F401
 except ImportError:
-    logging.warning(
-        "ElasticSearch package is not installed. Related functions cannot be used."
-    )
     ES_ENABLED = False
+    warnings.warn(
+        message="ElasticSearch package is not installed. Related functions cannot be used.",
+        category=ImportWarning,
+    )
 
 # subpackages
 from .parser import Listing, Lookup, Sign  # noqa: F401
