@@ -12,11 +12,11 @@
 import json
 import logging
 import re
-from pathlib import Path
 from time import gmtime, strftime
 from typing import List
 
 # 3rd party
+import geojson
 from isogeo_pysdk import Event, FeatureAttribute, Metadata, Workgroup
 
 # submodules
@@ -41,6 +41,8 @@ reg_digits_parentesis = re.compile(r"^.*?\([^\d]*(\d+)[^\d]*\).*$")
 class LookupToIsogeo:
     """Model converter from lookup to Isogeo model."""
 
+    COORDINATES_ROUND_LEVEL = 3
+
     def __init__(
         self, in_lookup: Lookup, isogeo_formats: list, isogeo_group: Workgroup,
     ):
@@ -105,11 +107,36 @@ class LookupToIsogeo:
 
         return out_feature_attributes
 
-    def extract_envelope(self) -> str:
-        """Extract envelope."""
+    def extract_envelope(self) -> dict:
+        """Load envelope as GeoJSON, validate it and reduce precision to be more light.
+
+        :return: geographic envelope as dict
+        :rtype: dict
+        """
         out_envelope = None
+
         if self.in_lookup.envelope:
-            out_envelope = json.loads(self.in_lookup.envelope)
+            try:
+                in_envelope = geojson.loads(self.in_lookup.envelope)
+                if not in_envelope.is_valid:
+                    logger.warning(
+                        "Envelope GeoJSON of '{}' is not valid: {}".format(
+                            self.in_lookup.name, in_envelope.errors()
+                        )
+                    )
+                # round coordinates
+                out_envelope = geojson.GeoJSON.to_instance(
+                    geojson.utils.map_coords(
+                        lambda x: round(x, self.COORDINATES_ROUND_LEVEL), in_envelope
+                    )
+                )
+            except Exception as err:
+                logger.error(
+                    "Failed loading the envelope from {}. Using the raw string."
+                    "Trace: {}".format(self.in_lookup.name),
+                    err,
+                )
+                out_envelope = json.loads(self.in_lookup.envelope)
 
         return out_envelope
 
