@@ -167,9 +167,9 @@ class Lookup(object):
         # warn about unsupported attributes
         if len(kwargs):
             logger.warning(
-                "Folllowings fields were not expected and have been ignored. "
-                "Maybe consider adding them to the model: {}.".format(
-                    " | ".join(kwargs.keys())
+                "Folllowing fields were not expected and have been ignored. "
+                "Maybe consider adding them to the model: {}. Object name: {}".format(
+                    " | ".join(kwargs.keys()), name
                 )
             )
 
